tlslite.constants.AlertDescription

Package tlslite :: Module constants :: Class AlertDescription |
[show private | hide private]
[frames | no frames]

## Class AlertDescription

Class Variable Summary
`int` | `access_denied` = 49
`int` | `bad_certificate` = 42
`int` | `bad_record_mac`: A TLS record failed to decrypt properly.
`int` | `certificate_expired` = 45
`int` | `certificate_revoked` = 44
`int` | `certificate_unknown` = 46
`int` | `close_notify` = 0
`int` | `decode_error` = 50
`int` | `decompression_failure` = 30
`int` | `decrypt_error` = 51
`int` | `decryption_failed` = 21
`int` | `export_restriction` = 60
`int` | `handshake_failure`: A problem occurred while handshaking.
`int` | `illegal_parameter` = 47
`int` | `insufficient_security` = 71
`int` | `internal_error` = 80
`int` | `missing_srp_username` = 121
`int` | `no_certificate` = 41
`int` | `no_renegotiation` = 100
`int` | `protocol_version`: The other party's SSL/TLS version was unacceptable.
`int` | `record_overflow` = 22
`int` | `unexpected_message` = 10
`int` | `unknown_ca` = 48
`int` | `unknown_srp_username` = 120
`int` | `unsupported_certificate` = 43
`int` | `untrusted_srp_parameters` = 122
`int` | `user_canceled`: The handshake is being cancelled for some reason.

Class Variable Details

    ### access_denied Type: `int` Value:
        49

    ### bad_certificate Type: `int` Value:
        42

    ### bad_record_mac A TLS record failed to decrypt properly. If this occurs during a shared-key or SRP handshake it most likely indicates a bad password. It may also indicate an implementation error, or some tampering with the data in transit. This alert will be signalled by the server if the SRP password is bad. It may also be signalled by the server if the SRP username is unknown to the server, but it doesn't wish to reveal that fact. This alert will be signalled by the client if the shared-key username is bad. Type: `int` Value:
        20

    ### certificate_expired Type: `int` Value:
        45

    ### certificate_revoked Type: `int` Value:
        44

    ### certificate_unknown Type: `int` Value:
        46

    ### close_notify Type: `int` Value:
        0

    ### decode_error Type: `int` Value:
        50

    ### decompression_failure Type: `int` Value:
        30

    ### decrypt_error Type: `int` Value:
        51

    ### decryption_failed Type: `int` Value:
        21

    ### export_restriction Type: `int` Value:
        60

    ### handshake_failure A problem occurred while handshaking. This typically indicates a lack of common ciphersuites between client and server, or some other disagreement (about SRP parameters or key sizes, for example). Type: `int` Value:
        40

    ### illegal_parameter Type: `int` Value:
        47

    ### insufficient_security Type: `int` Value:
        71

    ### internal_error Type: `int` Value:
        80

    ### missing_srp_username Type: `int` Value:
        121

    ### no_certificate Type: `int` Value:
        41

    ### no_renegotiation Type: `int` Value:
        100

    ### protocol_version The other party's SSL/TLS version was unacceptable. This indicates that the client and server couldn't agree on which version of SSL or TLS to use. Type: `int` Value:
        70

    ### record_overflow Type: `int` Value:
        22

    ### unexpected_message Type: `int` Value:
        10

    ### unknown_ca Type: `int` Value:
        48

    ### unknown_srp_username Type: `int` Value:
        120

    ### unsupported_certificate Type: `int` Value:
        43

    ### untrusted_srp_parameters Type: `int` Value:
        122

    ### user_canceled The handshake is being cancelled for some reason. Type: `int` Value:
        90

Generated by Epydoc 2.0 on Mon Feb 21 21:56:56 2005 | http://epydoc.sf.net